@@ -3,7 +3,7 @@
 # This file is part of gunicorn released under the MIT license. 
 # See the NOTICE for more information.
 
-
+import ctypes
 import grp
 import logging
 import optparse as op
@@ -24,7 +24,7 @@ LOG_LEVELS = {
     "debug": logging.DEBUG
 }
 
-UMASK = 0
+UMASK = "0"
 
 def options():
     """ build command lines options passed to OptParse object """
@@ -39,7 +39,7 @@ def options():
             help='set the background PID FILE'),
         op.make_option('-D', '--daemon', dest='daemon', action="store_true",
             help='Run daemonized in the background.'),
-        op.make_option('-m', '--umask', dest="umask", type='int', 
+        op.make_option('-m', '--umask', dest="umask", type='string', 
             help="Define umask of daemon process"),
         op.make_option('-u', '--user', dest="user", 
             help="Change worker user"),
@@ -106,7 +106,13 @@ def set_owner_process(user,group):
             gid = int(group)
         else:
             gid = grp.getgrnam(group).gr_gid
+        
+        try:
             os.setgid(gid)
+        except OverflowError:
+            # versions of python < 2.6.2 don't manage unsigned int for
+            # groups like on osx or fedora
+            os.setgid(-ctypes.c_int(-gid).value)
     if user:
         if user.isdigit() or isinstance(user, int):
             uid = int(user)
@@ -129,6 +135,7 @@ def main(usage, get_app):
     if conf['daemon']:
         daemonize(conf['umask'])
     else:
+        os.umask(conf['umask'])
         os.setpgrp()
     set_owner_process(conf['user'], conf['group']) 
     configure_logging(conf)
@@ -164,6 +171,7 @@ def paste_server(app, global_conf=None, host="127.0.0.1", port=None,
     if conf["daemon"] :
         daemonize(conf["umask"])
     else:
+        os.umask(conf['umask'])
         os.setpgrp()
     set_owner_process(conf["user"], conf["group"])
     configure_logging(conf)
